==> haskell-authenticate-1.3.3.2-48-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-authenticate.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: authenticate
version: 1.3.3.2
id: authenticate-1.3.3.2-7mopIYilk3w1N6hNukTQXh
key: authenticate-1.3.3.2-7mopIYilk3w1N6hNukTQXh
license: MIT
maintainer: Michael Snoyman <michael@snoyman.com>
stability: Stable
homepage: http://github.com/yesodweb/authenticate
synopsis: Authentication methods for Haskell web applications.
description:
    API docs and the README are available at <http://www.stackage.org/package/authenticate>.
category: Web
author: Michael Snoyman, Hiromi Ishii, Arash Rouhani
exposed: True
exposed-modules:
    Web.Authenticate.Rpxnow Web.Authenticate.OpenId
    Web.Authenticate.BrowserId Web.Authenticate.OpenId.Providers
hidden-modules: Web.Authenticate.Internal OpenId2.Discovery
                OpenId2.Normalization OpenId2.Types OpenId2.XRDS
abi: 9c687180cf7fda656dd1cd8f3778fc44
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/authenticate-1.3.3.2
library-dirs: /usr/lib/ghc-8.0.1/site-local/authenticate-1.3.3.2
data-dir: /usr/share/x86_64-linux-ghc-8.0.1/authenticate-1.3.3.2
hs-libraries: HSauthenticate-1.3.3.2-7mopIYilk3w1N6hNukTQXh
depends:
    aeson-1.0.2.1-580HLk2Nlp5BZ0wDg2BMVx
    attoparsec-0.13.1.0-6gEFbI8p8A3LThVdJgpVvH base-4.9.0.0
    blaze-builder-0.4.0.2-2VmGHau0mFrAjwd4n28WWF bytestring-0.10.8.1
    case-insensitive-1.2.0.8-6RHKQz6dPK3ENaPtabAPQ
    conduit-1.2.9-IqfCpUleYsf85Inkwdla2 containers-0.5.7.1
    http-conduit-2.2.3-1M3ZSKgvOkUH9nEqMRMQJb
    http-types-0.9.1-IFoDf4vkjVIKXmx1LMyAfY
    monad-control-1.0.1.0-CVvkY5Vr2NNGCNJRXug3iR
    network-uri-2.6.1.0-8yR4gjnzE4eDGhJR7PHfVJ
    resourcet-1.1.9-CymaqmR8zCeCrSnerfb4Fa
    tagstream-conduit-0.5.5.3-ATdacvHL7bu2kL0Xg9yqYf
    text-1.2.2.1-FgcR4Xf0VlEHD9HLxzq9WJ transformers-0.5.2.0
    unordered-containers-0.2.7.2-2cqAiy5FQsv48ljFn9vXL1
    xml-conduit-1.4.0.4-C5gqbUtQ6Lb8x9eYy50Usu
haddock-interfaces: /usr/share/doc/haskell-authenticate/html/authenticate.haddock
haddock-html: /usr/share/doc/haskell-authenticate/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-authenticate-1.3.3.2-68-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-authenticate.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: authenticate
version: 1.3.3.2
id: authenticate-1.3.3.2-UWjd9OU8AD4vHwslyUw63
key: authenticate-1.3.3.2-UWjd9OU8AD4vHwslyUw63
license: MIT
maintainer: Michael Snoyman <michael@snoyman.com>
stability: Stable
homepage: http://github.com/yesodweb/authenticate
synopsis: Authentication methods for Haskell web applications.
description:
    API docs and the README are available at <http://www.stackage.org/package/authenticate>.
category: Web
author: Michael Snoyman, Hiromi Ishii, Arash Rouhani
exposed: True
exposed-modules:
    Web.Authenticate.Rpxnow Web.Authenticate.OpenId
    Web.Authenticate.BrowserId Web.Authenticate.OpenId.Providers
hidden-modules: Web.Authenticate.Internal OpenId2.Discovery
                OpenId2.Normalization OpenId2.Types OpenId2.XRDS
abi: c5b34e32899d436813a5c95c08924481
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/authenticate-1.3.3.2
library-dirs: /usr/lib/ghc-8.0.1/site-local/authenticate-1.3.3.2
data-dir: /usr/share/x86_64-linux-ghc-8.0.1/authenticate-1.3.3.2
hs-libraries: HSauthenticate-1.3.3.2-UWjd9OU8AD4vHwslyUw63
depends:
    aeson-1.0.2.1-FrVhYmC6JHtKJ3ssqHzInY
    attoparsec-0.13.1.0-8c6XBOrZgakIL7qfHejbmf base-4.9.0.0
    blaze-builder-0.4.0.2-2VmGHau0mFrAjwd4n28WWF bytestring-0.10.8.1
    case-insensitive-1.2.0.8-19yABacCVqnEmCaYKTVngi
    conduit-1.2.9.1-GZZC8SxHl2s2gE2ucPFZOM containers-0.5.7.1
    http-conduit-2.2.3.1-BCLt1BnpYRmFMDLZQjVgHH
    http-types-0.9.1-DAWlwwLyGeDDnRhY9ftEgi
    monad-control-1.0.1.0-CVvkY5Vr2NNGCNJRXug3iR
    network-uri-2.6.1.0-8yR4gjnzE4eDGhJR7PHfVJ
    resourcet-1.1.9-CymaqmR8zCeCrSnerfb4Fa
    tagstream-conduit-0.5.5.3-HZmgmhAbrfBCK51QFR3Qy7
    text-1.2.2.1-FgcR4Xf0VlEHD9HLxzq9WJ transformers-0.5.2.0
    unordered-containers-0.2.8.0-HozSxlbOa6oDZVsS46CFCU
    xml-conduit-1.4.0.4-8B3uqSAzjMk1rnNqTAOhm0
haddock-interfaces: /usr/share/doc/haskell-authenticate/html/authenticate.haddock
haddock-html: /usr/share/doc/haskell-authenticate/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
